/* © 2024 Appstock */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the Appstock repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

//Superclass
#import <Foundation/Foundation.h>

#import "STKAdLoadManagerDelegate.h"
#import "STKAdViewManagerDelegate.h"
#import "STKCreativeViewDelegate.h"

@class STKModalManager;
@class STKAdConfiguration;
@class AppstockAdFormat;
@protocol STKModalManagerDelegate;
@protocol AppstockServerConnectionProtocol;

NS_ASSUME_NONNULL_BEGIN
@interface STKAdViewManager: NSObject <STKCreativeViewDelegate>

@property (nonatomic, strong) STKAdConfiguration *adConfiguration;
@property (nonatomic, strong) STKModalManager *modalManager;
@property (nonatomic, weak, nullable) id<STKAdViewManagerDelegate> adViewManagerDelegate;
@property (nonatomic, assign) BOOL autoDisplayOnLoad;
@property (nonatomic, readonly) BOOL isCreativeOpened;

@property (nonatomic, readonly, getter=isMuted) BOOL muted;

- (instancetype)init NS_UNAVAILABLE;
- (instancetype)initWithConnection:(id<AppstockServerConnectionProtocol>)connection
              modalManagerDelegate:(nullable id<STKModalManagerDelegate>)modalManagerDelegate NS_DESIGNATED_INITIALIZER;

- (nullable NSString*)revenueForNextCreative;

// Indicates whether the manager has all the needed data to show the add.
// If NO then the show method will not lead to displaying the ad.
- (BOOL)isAbleToShowCurrentCreative;

- (void)show;
- (void)pause;
- (void)resume;

- (void)mute;
- (void)unmute;


- (void)handleExternalTransaction:(STKTransaction *)transaction;

@end
NS_ASSUME_NONNULL_END
